import * as dotenv from 'dotenv';
import {ReceivedInvite} from './ReceivedInvite.interface';

dotenv.config();

const mariadb = require('mariadb');
const prod_pool = mariadb.createPool({
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.PARTYPLANER_PROD_DATABASE,
    connectionLimit: 5
});
const dev_pool = mariadb.createPool({
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.PARTYPLANER_DEV_DATABASE,
    connectionLimit: 5
});

/**
 * Returns all events the user is invited to
 * @param useDev If the dev or prod database should be used
 * @param userId The userId of the user to fetch the friends for
 * @return ReceivedInvite[] A list of invites
 */
export const getInvitesData = async (useDev: boolean, userId: string): Promise<ReceivedInvite[]> => {
    let conn;
    try {
        if (useDev) {
            conn = await dev_pool.getConnection();
        } else {
            conn = await prod_pool.getConnection();
        }

        let rows = await conn.query('SELECT i.invite_id, i.valid_until, i.already_used, i.invite_key, e.name as event_name, e.description as event_description, e.takes_place_date, e.registration_until_date, e.max_participants, e.creator_id, u.first_name, u.last_name FROM invitations i LEFT OUTER JOIN events e ON e.event_id = i.event_id LEFT OUTER JOIN users u ON u.user_id = e.creator_id WHERE i.user_id = ?', userId);

        let invites: ReceivedInvite[] = [];

        for (let row of rows) {
            invites.push({
                inviteId: row.invite_id,
                validUntil: row.valid_until,
                alreadyUsed: row.already_used,
                inviteKey: row.invite_key,
                eventName: row.event_name,
                eventDescription: row.event_description,
                takesPlaceDate: row.takes_place_date,
                registrationUntilDate: row.registration_until_date,
                maxParticipants: row.max_participants,
                eventCreatorId: row.creator_id,
                creatorFirstName: row.first_name,
                creatorLastName: row.last_name
            });
        }

        return invites;
    } catch (err) {
        throw err;
    } finally {
        if (conn) {
            conn.end();
        }
    }
};
